@@ -3,10 +3,12 @@ from django.conf.urls import include, url
 from rest_framework.renderers import (
     CoreJSONRenderer, DocumentationRenderer, SchemaJSRenderer
 )
-from rest_framework.schemas import get_schema_view
+from rest_framework.schemas import SchemaGenerator, get_schema_view
 
 
-def get_docs_view(title=None, description=None, schema_url=None, public=True):
+def get_docs_view(
+        title=None, description=None, schema_url=None, public=True,
+        patterns=None, generator_class=SchemaGenerator):
     renderer_classes = [DocumentationRenderer, CoreJSONRenderer]
 
     return get_schema_view(
@@ -14,11 +16,15 @@ def get_docs_view(title=None, description=None, schema_url=None, public=True):
         url=schema_url,
         description=description,
         renderer_classes=renderer_classes,
-        public=public
+        public=public,
+        patterns=patterns,
+        generator_class=generator_class,
     )
 
 
-def get_schemajs_view(title=None, description=None, schema_url=None, public=True):
+def get_schemajs_view(
+        title=None, description=None, schema_url=None, public=True,
+        patterns=None, generator_class=SchemaGenerator):
     renderer_classes = [SchemaJSRenderer]
 
     return get_schema_view(
@@ -26,22 +32,30 @@ def get_schemajs_view(title=None, description=None, schema_url=None, public=True
         url=schema_url,
         description=description,
         renderer_classes=renderer_classes,
-        public=public
+        public=public,
+        patterns=patterns,
+        generator_class=generator_class,
     )
 
 
-def include_docs_urls(title=None, description=None, schema_url=None, public=True):
+def include_docs_urls(
+        title=None, description=None, schema_url=None, public=True,
+        patterns=None, generator_class=SchemaGenerator):
     docs_view = get_docs_view(
         title=title,
         description=description,
         schema_url=schema_url,
-        public=public
+        public=public,
+        patterns=patterns,
+        generator_class=generator_class,
     )
     schema_js_view = get_schemajs_view(
         title=title,
         description=description,
         schema_url=schema_url,
-        public=public
+        public=public,
+        patterns=patterns,
+        generator_class=generator_class,
     )
     urls = [
         url(r'^$', docs_view, name='docs-index'),
