@@ -246,7 +246,9 @@ class EndpointInspector(object):
         Return a list of the valid HTTP methods for this endpoint.
         """
         if hasattr(callback, 'actions'):
-            return [method.upper() for method in callback.actions.keys()]
+            actions = set(callback.actions.keys())
+            http_method_names = set(callback.cls.http_method_names)
+            return [method.upper() for method in actions & http_method_names]
 
         return [
             method for method in
@@ -526,6 +528,7 @@ class SchemaGenerator(object):
             title = ''
             description = ''
             schema_cls = coreschema.String
+            kwargs = {}
             if model is not None:
                 # Attempt to infer a field description if possible.
                 try:
@@ -541,14 +544,16 @@ class SchemaGenerator(object):
                 elif model_field is not None and model_field.primary_key:
                     description = get_pk_description(model, model_field)
 
-                if isinstance(model_field, models.AutoField):
+                if hasattr(view, 'lookup_value_regex') and view.lookup_field == variable:
+                    kwargs['pattern'] = view.lookup_value_regex
+                elif isinstance(model_field, models.AutoField):
                     schema_cls = coreschema.Integer
 
             field = coreapi.Field(
                 name=variable,
                 location='path',
                 required=True,
-                schema=schema_cls(title=title, description=description)
+                schema=schema_cls(title=title, description=description, **kwargs)
             )
             fields.append(field)
 
@@ -600,7 +605,8 @@ class SchemaGenerator(object):
         if not is_list_view(path, method, view):
             return []
 
-        if not getattr(view, 'pagination_class', None):
+        pagination = getattr(view, 'pagination_class', None)
+        if not pagination or not getattr(pagination, 'page_size', None):
             return []
 
         paginator = view.pagination_class()
@@ -690,11 +696,16 @@ class SchemaView(APIView):
         return Response(schema)
 
 
-def get_schema_view(title=None, url=None, description=None, urlconf=None, renderer_classes=None, public=False):
+def get_schema_view(
+        title=None, url=None, description=None, urlconf=None, renderer_classes=None,
+        public=False, patterns=None, generator_class=SchemaGenerator):
     """
     Return a schema view.
     """
-    generator = SchemaGenerator(title=title, url=url, description=description, urlconf=urlconf)
+    generator = generator_class(
+        title=title, url=url, description=description,
+        urlconf=urlconf, patterns=patterns,
+    )
     return SchemaView.as_view(
         renderer_classes=renderer_classes,
         schema_generator=generator,
