@@ -1,6 +1,7 @@
 from __future__ import absolute_import, unicode_literals
 
 import re
+from collections import OrderedDict
 
 from django import template
 from django.template import loader
@@ -9,7 +10,9 @@ from django.utils.encoding import force_text, iri_to_uri
 from django.utils.html import escape, format_html, smart_urlquote
 from django.utils.safestring import SafeData, mark_safe
 
-from rest_framework.compat import NoReverseMatch, reverse, template_render
+from rest_framework.compat import (
+    NoReverseMatch, markdown, pygments_highlight, reverse, template_render
+)
 from rest_framework.renderers import HTMLFormRenderer
 from rest_framework.utils.urls import replace_query_param
 
@@ -19,6 +22,57 @@ register = template.Library()
 class_re = re.compile(r'(?<=class=["\'])(.*)(?=["\'])')
 
 
+@register.tag(name='code')
+def highlight_code(parser, token):
+    code = token.split_contents()[-1]
+    nodelist = parser.parse(('endcode',))
+    parser.delete_first_token()
+    return CodeNode(code, nodelist)
+
+
+class CodeNode(template.Node):
+    style = 'emacs'
+
+    def __init__(self, lang, code):
+        self.lang = lang
+        self.nodelist = code
+
+    def render(self, context):
+        text = self.nodelist.render(context)
+        return pygments_highlight(text, self.lang, self.style)
+
+
+@register.filter()
+def with_location(fields, location):
+    return [
+        field for field in fields
+        if field.location == location
+    ]
+
+
+@register.simple_tag
+def form_for_link(link):
+    import coreschema
+    properties = OrderedDict([
+        (field.name, field.schema or coreschema.String())
+        for field in link.fields
+    ])
+    required = [
+        field.name
+        for field in link.fields
+        if field.required
+    ]
+    schema = coreschema.Object(properties=properties, required=required)
+    return mark_safe(coreschema.render_to_form(schema))
+
+
+@register.simple_tag
+def render_markdown(markdown_text):
+    if not markdown:
+        return markdown_text
+    return mark_safe(markdown.markdown(markdown_text))
+
+
 @register.simple_tag
 def get_pagination_html(pager):
     return pager.to_html()
@@ -53,6 +107,22 @@ def optional_login(request):
     return mark_safe(snippet)
 
 
+@register.simple_tag
+def optional_docs_login(request):
+    """
+    Include a login snippet if REST framework's login view is in the URLconf.
+    """
+    try:
+        login_url = reverse('rest_framework:login')
+    except NoReverseMatch:
+        return 'log in'
+
+    snippet = "<a href='{href}?next={next}'>log in</a>"
+    snippet = format_html(snippet, href=login_url, next=escape(request.path))
+
+    return mark_safe(snippet)
+
+
 @register.simple_tag
 def optional_logout(request, user):
     """
@@ -163,6 +233,17 @@ def format_value(value):
     return six.text_type(value)
 
 
+@register.filter
+def items(value):
+    """
+    Simple filter to return the items of the dict. Useful when the dict may
+    have a key 'items' which is resolved first in Django tempalte dot-notation
+    lookup.  See issue #4931
+    Also see: https://stackoverflow.com/questions/15416662/django-template-loop-over-dictionary-items-with-items-as-key
+    """
+    return value.items()
+
+
 @register.filter
 def add_nested_class(value):
     if isinstance(value, dict):
